<?xml version = "1.0" encoding = "UTF-8" ?>

<!-- ====================================================================== 

     ====================================================================== -->

<xsl:stylesheet xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" 
                xmlns:x   = "http://www.w3.org/XML/1998/namespace"
		xmlns:doc = "http://xsltsl.org/xsl/documentation/1.0"
                exclude-result-prefixes = "doc"
                version   = "1.0">

<!-- ====================================================================== 

     ====================================================================== -->

     <doc:reference>
      <referenceinfo>

       <title>find-articles</title>

       <abstract>
        <para>This is an <acronym>XSLT</acronym> 1.0 stylesheet for
        pruning a collection of (DocBook) articles by ID, title or author.</para>

       </abstract>

       <author>
	<surname>Cope</surname>
	<firstname>Aaron</firstname>
	<othername>Straup</othername>
	<email>aaron@aaronland.net</email>
       </author>

       <legalnotice>
        <para>This work is licensed under the Creative Commons
        Attribution-ShareAlike License. To view a copy of this
        license, visit <ulink url = "http://creativecommons.org/licenses/by-sa/1.0/">http://creativecommons.org/licenses/by-sa/1.0/</ulink> or send a letter to Creative Commons, 559 Nathan Abbott Way,
        Stanford, California 94305, USA.</para> 
       </legalnotice>

       <revhistory>
        <revision>
	 <revnumber>1.0</revnumber>
	 <date>2004-10-23</date>
	 <revremark>
	  <para>Initial release.</para>
         </revremark>
	</revision>
       </revhistory>

      </referenceinfo>

      <refentry>
       <refsection>
        <title>Usage</title>

	<example>
	 <programlisting><![CDATA[
 # prune list of articles by author

 $> xsltproc -o ~/tmp/kraus.xml \
             --stringparam author 'Clifford Krauss' \
             ./find-articles.xsl \
             /nyt/2004/10/03.xml

 # generate XSL-FO document

 $> xsltproc -o ~/tmp/krauss.fo \
             /path/to/docbook/fo.xsl \
             ~/tmp/krauss.xml

 # generate PDF file

 $> fop -fo  ~/tmp/krauss.fo 
        -pdf ~/tmp/krauss.pdf
]]></programlisting>
	</example>
	 
	<para>Consult the documentation for your favourite
       <acronym>XSLT</acronym> processor. This template accepts the
       following parameters, in order of precedence : </para>

	<itemizedlist>

	 <listitem>
	  <formalpara>
	   <title>id</title>
	   <para>String. Typically a URL, this is the unique ID
	  associated with an article.</para>
	  </formalpara> 
         </listitem>

	 <listitem>
	  <formalpara>
	   <title>title</title>
	   <para>String. The title assigned to an article in its
	  articleinfo section.</para>
	  </formalpara> 
         </listitem>

	 <listitem>
	  <formalpara>
	   <title>author</title>
	   <para>String. The first name and surname, separated by a
	  single space, of an author assigned to an article in its
	  articlinfo /authorgroup /author section(s).</para>
	  </formalpara> 
         </listitem>

	</itemizedlist>

       </refsection>

       <refsection>
        <title>Requirements</title>
	<para>Nothing special.</para>
       </refsection>

      </refentry>

     </doc:reference>

<!-- ====================================================================== 

     ====================================================================== -->

     <xsl:output method         = "xml" />
     <xsl:output encoding       = "ISO-8859-1" />
     <xsl:output indent         = "yes" />

     <xsl:param name = "id"     />
     <xsl:param name = "author" />
     <xsl:param name = "title"  />

<!-- ====================================================================== 

     ====================================================================== -->

     <xsl:template match="/">

      <xsl:choose>
       <xsl:when test = "$id">
        <xsl:copy-of select = "*//article[starts-with(@id,$id)]" />
       </xsl:when>
       <xsl:when test = "$title">
        <xsl:copy-of select = "*//articleinfo[title=$title]/parent::*" />
       </xsl:when>
       <xsl:when test = "$author">
        <xsl:call-template name = "find-for-author" />     
       </xsl:when>
       <xsl:otherwise>
        <xsl:message>
         <xsl:text>Usage : $xsl_processor --stringparam (id|title|author) $value</xsl:text>
        </xsl:message>
       </xsl:otherwise>
      </xsl:choose>

     </xsl:template>

<!-- ====================================================================== 

     ====================================================================== -->

     <xsl:template name = "find-for-author">
      <xsl:variable name = "first" select = "substring-before($author,' ')" />
      <xsl:variable name = "last"  select = "substring-after($author,' ')" />

      <xsl:variable name = "list" select = "*//articleinfo/authorgroup/author[firstname=$first and surname=$last]/parent::*/parent::*/parent::*" />

      <xsl:variable name = "count" select = "count($list)" />

      <xsl:choose>
       <xsl:when test = "$count > 1">
        <book>
         <bookinfo>
          <title>
	   <xsl:text>Articles by </xsl:text>
	   <xsl:value-of select = "$author" />
	  </title>
	  <pubdate>
	   <xsl:value-of select = "substring-before(/book/bookinfo/pubdate,'T')" />
	  </pubdate>
         </bookinfo>
         <xsl:for-each select = "$list">
          <xsl:copy-of select = "." />
         </xsl:for-each>      
        </book>
       </xsl:when>

       <xsl:otherwise>
        <xsl:copy-of select = "$list" />
       </xsl:otherwise>

      </xsl:choose>

     </xsl:template>

<!-- ====================================================================== 
     FIN // $Id: find-articles.xsl,v 1.1 2004/10/23 16:15:43 asc Exp $
     ====================================================================== -->

</xsl:stylesheet>
